<?php

namespace App\Entity;

use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity]
class Skill
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 30)]
    private ?string $label = null;

    #[ORM\OneToMany(targetEntity: Requirement::class, mappedBy: 'skill')]
    #[ORM\JoinColumn(referencedColumnName: 'skill')]
    private Collection $requirements;

    #[ORM\OneToMany(targetEntity: EmployeeSkill::class, mappedBy: 'skill')]
    #[ORM\JoinColumn(referencedColumnName: 'skill')]
    private Collection $employeeSkills;

    public function getRequirements(): Collection
    {
        return $this->requirements;
    }

    public function addRequirement(Requirement $requirement): static
    {
        if(!$this->requirements->contains($requirement)) {
            $this->requirements->add($requirement);
            $requirement->setSkill($this);
        }

        return $this;
    }

    public function removeRequirement(Requirement $requirement): static
    {
        if($this->requirements->removeElement($requirement)) {
            if($requirement->getSkill() === $this) {
                $requirement->setSkill(null);
            }
        }

        return $this;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function setId(int $id): static
    {
        $this->id = $id;

        return $this;
    }

    public function getLabel(): ?string
    {
        return $this->label;
    }

    public function setLabel(string $label): static
    {
        $this->label = $label;

        return $this;
    }

    public function getEmployeeSkills(): Collection
    {
        return $this->employeeSkills;
    }

    public function addEmployeeSkill(EmployeeSkill $employeeSkill): static
    {
        if(!$this->employeeSkills->contains($employeeSkill)) {
            $this->employeeSkills->add($employeeSkill);
            $employeeSkill->setSkill($this);
        }

        return $this;
    }

    public function removeEmployeeSkill(EmployeeSkill $employeeSkill): static
    {
        if($this->employeeSkills->removeElement($employeeSkill)) {
            if($employeeSkill->getSkill() === $this) {
                $employeeSkill->setSkill(null);
            }
        }

        return $this;
    }

}
